@@ -13,7 +13,11 @@
 #' # Create a named vector
 #' name_vec(content = 1:10, name = paste0("text_", 1:10))
 #' 
-name_vec <- function(content, name){
+name_vec <- function(content = NULL, name = NULL){
+  
+  # Error out either is not provided
+  if(is.null(content) == TRUE | is.null(name) == TRUE)
+    stop("Both arguments must be specified")
   
   # Error out if content & name are not the same length
   if(length(x = content) != length(x = name))
